.. pywib documentation master file, created by
   sphinx-quickstart on Mon Oct  6 13:40:36 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pywib documentation
===================

Pywib (Python Web Interaction Behavior) is a library designed to analyze user interaction data from web applications. It provides tools to process, analyze, and visualize user behavior patterns, helping developers and researchers understand how users interact with their web interfaces.

The library includes various modules for different aspects of web interaction analysis, such as movement tracking, timing analysis, and pause detection.

Contents
---------

.. toctree::
   :maxdepth: 2

   introduction
   movement
   trajectory
   mouse
   keyboard
   timing
   constants
   api/index

This library has been developed by the `HCI research group <https://www.hci.uniovi.es/>`_ from the University of Oviedo and is maintained on `GitHub <https://github.com/HumanCommunicationInteraction/pywib>`_.